@@ -1,4 +1,5 @@
 <?php
+
 /* vim: set expandtab softtabstop=4 tabstop=4 shiftwidth=4: */
 
 # Note: run with upgrade.php?debug=1 to see all SQL error messages
@@ -1957,3 +1958,50 @@ function upgrade_1844() {
 
     _db_add_field('domain_admins', 'id', '{AUTOINCREMENT} {PRIMARY}');
 }
+
+function upgrade_1845() {
+    # See: https://github.com/postfixadmin/postfixadmin/pull/484
+    #
+    if (!db_mysql()) {
+        return;
+    }
+
+    $vacation = table_by_key('vacation');
+    $mailbox = table_by_key('mailbox');
+    db_query("alter table $vacation change body body text charset utf8mb4 not null");
+    db_query("alter table $vacation change subject subject varchar(255) charset utf8mb4 not null");
+    db_query("alter table $mailbox change name name varchar(255) charset utf8mb4 not null");
+}
+
+function upgrade_1846_mysql() {
+    # See https://github.com/postfixadmin/postfixadmin/issues/327
+
+    $alias = table_by_key('alias');
+    $domain = table_by_key('domain');
+    $mailbox = table_by_key('mailbox');
+    $vacation = table_by_key('vacation');
+    $vacation_notification = table_by_key('vacation_notification');
+    $alias_domain = table_by_key('alias_domain');
+    $domain_admins = table_by_key('domain_admins');
+
+    db_query("ALTER TABLE $alias MODIFY address varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $alias MODIFY goto text  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $alias MODIFY domain varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $domain MODIFY domain varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $domain MODIFY transport varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $mailbox MODIFY username varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $mailbox MODIFY password varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $mailbox MODIFY maildir varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $mailbox MODIFY local_part varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $mailbox MODIFY domain varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $vacation_notification DROP CONSTRAINT vacation_notification_pkey");
+    db_query("ALTER TABLE $vacation MODIFY domain varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $vacation MODIFY email varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $alias_domain MODIFY alias_domain varchar(255)  COLLATE latin1_general_ci NOT NULL DEFAULT ''");
+    db_query("ALTER TABLE $alias_domain MODIFY target_domain varchar(255)  COLLATE latin1_general_ci NOT NULL DEFAULT ''");
+
+    db_query("ALTER TABLE $vacation_notification MODIFY on_vacation VARCHAR(255) COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $vacation_notification ADD CONSTRAINT vacation_notification_pkey FOREIGN KEY (`on_vacation`) REFERENCES $vacation(email) ON DELETE CASCADE");
+
+    db_query("ALTER TABLE $domain_admins MODIFY `domain` varchar(255) COLLATE latin1_general_ci NOT NULL");
+}
